@@ -8,7 +8,7 @@ import (
 	"github.com/coreos/go-semver/semver"
 	vfs "github.com/twpayne/go-vfs/v5"
 
-	"github.com/twpayne/chezmoi/internal/chezmoitest"
+	"chezmoi.io/chezmoi/internal/chezmoitest"
 )
 
 var _ System = &DumpSystem{}
