@@ -6,7 +6,7 @@ import (
 	"github.com/alecthomas/assert/v2"
 	vfs "github.com/twpayne/go-vfs/v5"
 
-	"github.com/twpayne/chezmoi/internal/chezmoitest"
+	"chezmoi.io/chezmoi/internal/chezmoitest"
 )
 
 func TestPatternSet(t *testing.T) {
