@@ -16,9 +16,9 @@ import (
 	"github.com/spf13/pflag"
 	bbolterrors "go.etcd.io/bbolt/errors"
 
-	"github.com/twpayne/chezmoi/internal/chezmoi"
-	"github.com/twpayne/chezmoi/internal/chezmoierrors"
-	"github.com/twpayne/chezmoi/internal/chezmoiset"
+	"chezmoi.io/chezmoi/internal/chezmoi"
+	"chezmoi.io/chezmoi/internal/chezmoierrors"
+	"chezmoi.io/chezmoi/internal/chezmoiset"
 )
 
 const readSourceStateHookName = "read-source-state"
@@ -65,8 +65,8 @@ func Main(versionInfo VersionInfo, args []string) int {
 	return 0
 }
 
-// deDuplicateError returns err's human-readable string with duplicate components
-// removed.
+// deDuplicateError returns err's human-readable string with duplicate
+// components removed.
 func deDuplicateError(err error) string {
 	components := deDuplicateErrorRx.Split(err.Error(), -1)
 	seenComponents := chezmoiset.NewWithCapacity[string](len(components))
