@@ -24,9 +24,9 @@ import (
 	"github.com/twpayne/go-shell"
 	"github.com/twpayne/go-xdg/v6"
 
-	"github.com/twpayne/chezmoi/internal/chezmoi"
-	"github.com/twpayne/chezmoi/internal/chezmoigit"
-	"github.com/twpayne/chezmoi/internal/chezmoilog"
+	"chezmoi.io/chezmoi/internal/chezmoi"
+	"chezmoi.io/chezmoi/internal/chezmoigit"
+	"chezmoi.io/chezmoi/internal/chezmoilog"
 )
 
 // A checkResult is the result of a check.
