@@ -14,8 +14,8 @@ import (
 	"github.com/go-git/go-git/v5/plumbing/transport/http"
 	"github.com/spf13/cobra"
 
-	"github.com/twpayne/chezmoi/internal/chezmoi"
-	"github.com/twpayne/chezmoi/internal/chezmoilog"
+	"chezmoi.io/chezmoi/internal/chezmoi"
+	"chezmoi.io/chezmoi/internal/chezmoilog"
 )
 
 type initCmdConfig struct {
@@ -204,8 +204,12 @@ func (c *Config) runInitCmd(cmd *cobra.Command, args []string) error {
 		}
 	}
 
-	// Apply.
+	// Apply. Explicitly run any apply pre or post hooks because the normal hook
+	// mechanism will only run init's hooks.
 	if c.init.apply {
+		if err := c.runHookPre("apply"); err != nil {
+			return err
+		}
 		if err := c.applyArgs(cmd.Context(), c.destSystem, c.DestDirAbsPath, noArgs, applyArgsOptions{
 			cmd:          cmd,
 			filter:       c.init.filter,
@@ -215,6 +219,9 @@ func (c *Config) runInitCmd(cmd *cobra.Command, args []string) error {
 		}); err != nil {
 			return err
 		}
+		if err := c.runHookPost("apply"); err != nil {
+			return err
+		}
 	}
 
 	// Purge.
