@@ -29,9 +29,9 @@ import (
 	"github.com/twpayne/go-vfs/v5"
 	"github.com/twpayne/go-vfs/v5/vfst"
 
-	"github.com/twpayne/chezmoi/internal/chezmoi"
-	"github.com/twpayne/chezmoi/internal/chezmoitest"
-	"github.com/twpayne/chezmoi/internal/cmd"
+	"chezmoi.io/chezmoi/internal/chezmoi"
+	"chezmoi.io/chezmoi/internal/chezmoitest"
+	"chezmoi.io/chezmoi/internal/cmd"
 )
 
 var (
@@ -325,7 +325,8 @@ func cmdIsSymlink(ts *testscript.TestScript, neg bool, args []string) {
 	}
 }
 
-// cmdLExists succeeds if all if its arguments exist, without following symlinks.
+// cmdLExists succeeds if all if its arguments exist, without following
+// symlinks.
 func cmdLExists(ts *testscript.TestScript, neg bool, args []string) {
 	if len(args) == 0 {
 		ts.Fatalf("usage: exists file...")
