@@ -24,8 +24,8 @@ import (
 	"gopkg.in/ini.v1"
 	"howett.net/plist"
 
-	"github.com/twpayne/chezmoi/internal/chezmoi"
-	"github.com/twpayne/chezmoi/internal/chezmoilog"
+	"chezmoi.io/chezmoi/internal/chezmoi"
+	"chezmoi.io/chezmoi/internal/chezmoilog"
 )
 
 type ioregData struct {
@@ -41,7 +41,8 @@ func (e emptyPathElementError) Error() string {
 	return fmt.Sprintf("empty path element at index %d", e.index)
 }
 
-// An invalidPathElementTypeError is returned when an element in a path has an invalid type.
+// An invalidPathElementTypeError is returned when an element in a path has an
+// invalid type.
 type invalidPathElementTypeError struct {
 	element any
 }
